summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger/gdbcontroller.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/debugger/gdbcontroller.cpp')
-rw-r--r--languages/cpp/debugger/gdbcontroller.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/languages/cpp/debugger/gdbcontroller.cpp b/languages/cpp/debugger/gdbcontroller.cpp
index 15ebcdfc..a46b6d6a 100644
--- a/languages/cpp/debugger/gdbcontroller.cpp
+++ b/languages/cpp/debugger/gdbcontroller.cpp
@@ -796,19 +796,19 @@ bool GDBController::start(const TQString& shell, const DomUtil::PairList& run_en
Q_ASSERT (!dbgProcess_ && !tty_);
- dbgProcess_ = new KProcess;
+ dbgProcess_ = new TDEProcess;
- connect( dbgProcess_, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)),
- this, TQT_SLOT(slotDbgStdout(KProcess *, char *, int)) );
+ connect( dbgProcess_, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
+ this, TQT_SLOT(slotDbgStdout(TDEProcess *, char *, int)) );
- connect( dbgProcess_, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)),
- this, TQT_SLOT(slotDbgStderr(KProcess *, char *, int)) );
+ connect( dbgProcess_, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
+ this, TQT_SLOT(slotDbgStderr(TDEProcess *, char *, int)) );
- connect( dbgProcess_, TQT_SIGNAL(wroteStdin(KProcess *)),
- this, TQT_SLOT(slotDbgWroteStdin(KProcess *)) );
+ connect( dbgProcess_, TQT_SIGNAL(wroteStdin(TDEProcess *)),
+ this, TQT_SLOT(slotDbgWroteStdin(TDEProcess *)) );
- connect( dbgProcess_, TQT_SIGNAL(processExited(KProcess*)),
- this, TQT_SLOT(slotDbgProcessExited(KProcess*)) );
+ connect( dbgProcess_, TQT_SIGNAL(processExited(TDEProcess*)),
+ this, TQT_SLOT(slotDbgProcessExited(TDEProcess*)) );
application_ = application;
@@ -838,8 +838,8 @@ bool GDBController::start(const TQString& shell, const DomUtil::PairList& run_en
" --interpreter=mi2 -quiet\n" ).latin1());
}
- if (!dbgProcess_->start( KProcess::NotifyOnExit,
- KProcess::Communication(KProcess::All)))
+ if (!dbgProcess_->start( TDEProcess::NotifyOnExit,
+ TDEProcess::Communication(TDEProcess::All)))
{
KMessageBox::information(
0,
@@ -1126,12 +1126,12 @@ void GDBController::slotRun()
TQCString tty(tty_->getSlave().latin1());
TQCString options = TQCString(">") + tty + TQCString(" 2>&1 <") + tty;
- KProcess *proc = new KProcess;
+ TDEProcess *proc = new TDEProcess;
*proc << "sh" << "-c";
*proc << config_runShellScript_ +
" " + application_.latin1() + options;
- proc->start(KProcess::DontCare);
+ proc->start(TDEProcess::DontCare);
}
if (!config_runGdbScript_.isEmpty()) {// gdb script at run is requested
@@ -1421,13 +1421,13 @@ void GDBController::processMICommandResponse(const GDBMI::ResultRecord& result)
}
// Data from gdb gets processed here.
-void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
+void GDBController::slotDbgStdout(TDEProcess *, char *buf, int buflen)
{
static bool parsing = false;
TQCString msg(buf, buflen+1);
// Copy the data out of the KProcess buffer before it gets overwritten
// Append to the back of the holding zone.
holdingZone_ += TQCString(buf, buflen+1);
@@ -1685,7 +1685,7 @@ void GDBController::raiseEvent(event_t e)
}
-void GDBController::slotDbgStderr(KProcess *proc, char *buf, int buflen)
+void GDBController::slotDbgStderr(TDEProcess *proc, char *buf, int buflen)
{
// At the moment, just drop a message out and redirect
kdDebug(9012) << "STDERR: " << TQString::fromLatin1(buf, buflen+1) << endl;
@@ -1694,7 +1694,7 @@ void GDBController::slotDbgStderr(KProcess *proc, char *buf, int buflen)
// **************************************************************************
-void GDBController::slotDbgWroteStdin(KProcess *)
+void GDBController::slotDbgWroteStdin(TDEProcess *)
{
commandExecutionTime.start();
@@ -1706,7 +1706,7 @@ void GDBController::slotDbgWroteStdin(KProcess *)
// **************************************************************************
-void GDBController::slotDbgProcessExited(KProcess* process)
+void GDBController::slotDbgProcessExited(TDEProcess* process)
{
Q_ASSERT(process == dbgProcess_);
bool abnormal = !process->normalExit();
@@ -1421,13 +1421,13 @@ void GDBController::processMICommandResponse(const GDBMI::ResultRecord& result)
static bool parsing = false;
TQCString msg(buf, buflen+1);
- // Copy the data out of the KProcess buffer before it gets overwritten
+ // Copy the data out of the TDEProcess buffer before it gets overwritten
// Append to the back of the holding zone.
holdingZone_ += TQCString(buf, buflen+1);